@@ -68,7 +68,12 @@
   (setq gnus-undo-mode-map (make-sparse-keymap))
 
   (gnus-define-keys gnus-undo-mode-map
-   "\M-\C-_" gnus-undo))
+   "\M-\C-_"     gnus-undo
+   "\C-_"        gnus-undo
+   "\C-xu"       gnus-undo
+   [(control /)] gnus-undo    ; many people are used to type `C-/' on
+			      ; X terminals and get `C-_'.
+   ))
 
 (defun gnus-undo-make-menu-bar ()
   (when nil
@@ -96,7 +101,7 @@
     (unless (assq 'gnus-undo-mode minor-mode-map-alist)
       (push (cons 'gnus-undo-mode gnus-undo-mode-map)
 	    minor-mode-map-alist))
-    (gnus-make-local-hook 'post-command-hook)
+    (make-local-hook 'post-command-hook)
     (gnus-add-hook 'post-command-hook 'gnus-undo-boundary nil t)
     (add-hook 'gnus-summary-exit-hook 'gnus-undo-boundary)
     (run-hooks 'gnus-undo-mode-hook)))
