@@ -225,7 +225,7 @@ time saver for large mailboxes.")
        (let ((bufs nnfolder-buffer-alist))
 	 (save-excursion
 	   (while bufs
-	     (if (not (buffer-live-p (nth 1 (car bufs))))
+	     (if (not (gnus-buffer-live-p (nth 1 (car bufs))))
 		 (setq nnfolder-buffer-alist
 		       (delq (car bufs) nnfolder-buffer-alist))
 	       (set-buffer (nth 1 (car bufs)))
@@ -375,16 +375,23 @@ time saver for large mailboxes.")
        (forward-line -1)
        (while (re-search-backward (concat "^" nnfolder-article-marker) nil t)
 	 (delete-region (point) (progn (forward-line 1) (point))))
-       (setq result
-	     (car (nnfolder-save-mail
-		   (if (stringp group)
-		       (list (cons group (nnfolder-active-number group)))
-		     (setq art-group
-			   (nnmail-article-group 'nnfolder-active-number)))))))
+       (when nnmail-cache-accepted-message-ids
+	 (nnmail-cache-insert (nnmail-fetch-field "message-id")))
+       (setq result (if (stringp group)
+			(list (cons group (nnfolder-active-number group)))
+		      (setq art-group
+			    (nnmail-article-group 'nnfolder-active-number))))
+       (if (and (null result)
+		(yes-or-no-p "Moved to `junk' group; delete article? "))
+	   (setq result 'junk)
+	 (setq result
+	       (car (nnfolder-save-mail result)))))
      (when last
        (save-excursion
 	 (nnfolder-possibly-change-folder (or (caar art-group) group))
-	 (nnfolder-save-buffer))))
+	 (nnfolder-save-buffer)
+	 (when nnmail-cache-accepted-message-ids
+	   (nnmail-cache-close)))))
     (nnmail-save-active nnfolder-group-alist nnfolder-active-file)
     (unless result
       (nnheader-report 'nnfolder "Couldn't store article"))
@@ -572,12 +579,13 @@ time saver for large mailboxes.")
 	      (end (point-max))
 	      (obuf (current-buffer)))
 	  (nnfolder-possibly-change-folder (car group-art))
-	  (goto-char (point-max))
-	  (unless (eolp)
-	    (insert "\n"))
-	  (unless (bobp)
-	    (insert "\n"))
-	  (insert-buffer-substring obuf beg end))))
+	  (let ((buffer-read-only nil))
+	    (goto-char (point-max))
+	    (unless (eolp)
+	      (insert "\n"))
+	    (unless (bobp)
+	      (insert "\n"))
+	    (insert-buffer-substring obuf beg end)))))
 
     ;; Did we save it anywhere?
     save-list))
@@ -643,7 +651,8 @@ time saver for large mailboxes.")
 	(let ((delim (concat "^" message-unix-mail-delimiter))
 	      (marker (concat "\n" nnfolder-article-marker))
 	      (number "[0-9]+")
-	      (active (cadr (assoc group nnfolder-group-alist)))
+	      (active (or (cadr (assoc group nnfolder-group-alist))
+			  (cons 1 0)))
 	      (scantime (assoc group nnfolder-scantime-alist))
 	      (minid (lsh -1 -1))
 	      maxid start end newscantime
@@ -676,10 +685,10 @@ time saver for large mailboxes.")
 	  (when (not (or nnfolder-distrust-mbox
 			 (< maxid 2)))
 	    (goto-char (point-max))
-	    (if (not (re-search-backward marker nil t))
-		(goto-char (point-min))
-	      (when (not (nnmail-search-unix-mail-delim))
-		(goto-char (point-min)))))
+	    (unless (re-search-backward marker nil t)
+	      (goto-char (point-min)))
+	    (when (nnmail-search-unix-mail-delim)
+	      (goto-char (point-min))))
 
 	  ;; Keep track of the active number on our own, and insert it back
 	  ;; into the active list when we're done.  Also, prime the pump to
